/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies;

/**
 * Constant values used by PDR-Allies client and server side (e.g. element names
 * of the underlying AxiOM XML).
 * @author Fabian Körner
 */
public final class AlliesConstants
{

	/** Encoding used for data parts of all HTTP Post requests. */
	public static final String HTTP_POST_DATA_ENCODING = "UTF-8";

	/* Common keys and values of HTTP Post header options. */
	/** Key and Value of HTTP Post header option: content-type. */
	public static final AlliesConstants.KeyValuePair HTTP_POST_HEADER_CONTENT_TYPE =
			new AlliesConstants.KeyValuePair("Content-Type", "application/x-www-form-urlencoded");
	/** Key and Value of HTTP Post header option: accept. */
	public static final AlliesConstants.KeyValuePair HTTP_POST_HEADER_ACCEPT =
			new AlliesConstants.KeyValuePair("Accept", "*/*");
	/** Key and Value of HTTP Post header option: connection. */
	public static final AlliesConstants.KeyValuePair HTTP_POST_HEADER_CONNECTION =
			new AlliesConstants.KeyValuePair("Connection", "close");

	/* Element names in Axiom OM trees */
	/** Element name: Categories. */
	public static final String OMCHILD_LNAME_CATEGORIES = "Categories";
	/** Element name: Credentials. */
	public static final String OMCHILD_LNAME_CREDENTIALS = "Credentials";
	/** Element name: demand unproportional force. */
	public static final String OMCHILD_LNAME_FORCE = "Force";
	/** Element name: ID. */
	public static final String OMCHILD_LNAME_ID = "Id";
	/** Element name: instance ID. */
	public static final String OMCHILD_LNAME_INSTANCE = "Instance";
	/** Element name: any kind of keys. */
	public static final String OMCHILD_LNAME_KEY = "Key";
	/** Element name: key-value pair. */
	public static final String OMCHILD_LNAME_KEY_VALUE_PAIR = "KeyValuePair";
	/** Element name: Map. */
	public static final String OMCHILD_LNAME_MAP = "Map";
	/** Element name: maximum. */
	public static final String OMCHILD_LNAME_MAX = "Max";
	/** Element name: minimum. */
	public static final String OMCHILD_LNAME_MIN = "Min";
	/** Element name: PDR object. */
	public static final String OMCHILD_LNAME_OBJECT = "Object";
	/** Element name: collection of PDR objects. */
	public static final String OMCHILD_LNAME_OBJECTS = "Objects";
	/** Element name: project ID. */
	public static final String OMCHILD_LNAME_PROJECT = "Project";
	/** Element name: provider name. */
	public static final String OMCHILD_LNAME_PROVIDER = "Provider";
	/** Element name: collection of provider names. */
	public static final String OMCHILD_LNAME_PROVIDERS = "Providers";
	/** Element name: query. */
	public static final String OMCHILD_LNAME_QUERY = "Query";
	/** Element name: range. */
	public static final String OMCHILD_LNAME_RANGE = "Range";
	/** Element name: collection of ranges. */
	public static final String OMCHILD_LNAME_RANGES = "Ranges";
	/** Element name: reason (e.g. in SOAP error messages). */
	public static final String OMCHILD_LNAME_REASON = "Reason";
	/** Element name: response of another service. */
	public static final String OMCHILD_LNAME_RESPONSE = "Response";
	/** Element name: textual information. */
	public static final String OMCHILD_LNAME_TEXT = "Text";
	/** Element name: timestamp (YYYY-MM-DDThh:mm:ss). */
	public static final String OMCHILD_LNAME_TIMESTAMP = "Timestamp";
	/** Element name: type. */
	public static final String OMCHILD_LNAME_TYPE = "Type";
	/** Element name: value. */
	public static final String OMCHILD_LNAME_VALUE = "Value";
	/** Element name: username. */
	public static final String OMCHILD_LNAME_USER = "User";
	/** Element name: password. */
	public static final String OMCHILD_LNAME_PASS = "Pass";

	/** Element name of response: getModifiedObjects. */
	public static final String OMCHILD_REPOSITORY_GET_MODIFIED_OBJECTS_RESPONSE = "getModifiedObjectsResponse";
	/** Element name of response: getProjectSizes. */
	public static final String OMCHILD_REPOSITORY_GET_PROJECT_SIZES_RESPONSE = "getProjectSizesResponse";
	public static final String OMCHILD_REPOSITORY_GET_TIME_REPSONSE = "getTimeResponse";
	public static final String OMCHILD_REPOSITORY_GET_USER_ID_REPSONSE = "getUserIDResponse";
	/** Element name of response: getModifiedObjects. */
	public static final String OMCHILD_REPOSITORY_INGEST_OBJECTS_RESPONSE = "ingestObjectsResponse";
	/** Element name of response: modifyObjects. */
	public static final String OMCHILD_REPOSITORY_MODIFY_OBJECTS_RESPONSE = "modifyObjectsResponse";
	/** Element name of response: selectSolr. */
	public static final String OMCHILD_REPOSITORY_SOLR_SELECT_RESPONSE = "solrSelectResponse";
	/** Element name of response: echo. */
	public static final String OMCHILD_UTILITIES_ECHO_RESPONSE = "echoResponse";
	/** Element name of response: getVersion. */
	public static final String OMCHILD_UTILITIES_GET_VERSION_RESPONSE = "getVersionResponse";
	/** Element name of response: getOccupiedIDRanges. */
	public static final String OMCHILD_UTILITIES_GET_OCCUPIED_ID_RANGES_RESPONSE = "getOccupiedIDRangesResponse";
	/** Element name of response: getObject. */
	public static final String OMCHILD_UTILITIES_GET_OBJECT_RESPONSE = "getObjectResponse";
	/** Element name of response: getObjects. */
	public static final String OMCHILD_UTILITIES_GET_OBJECTS_RESPONSE = "getObjectsResponse";
	/** Element name of response: getCategories. */
	public static final String OMCHILD_UTILITIES_GET_CATEGORIES_RESPONSE = "getCategoriesResponse";
	/** Element name of response: getCategoryProvidersResponse. */
	public static final String OMCHILD_UTILITIES_GET_CATEGORY_PROVIDERS_RESPONSE = "getCategoryProvidersResponse";
	/** Element name of response: optimizeIndex. */
	public static final String OMCHILD_UTILITIES_IS_INDEX_OPTIMIZED_RESPONSE = "isIndexOptimizedResponse";
	/** Element name of response: optimizeIndex. */
	public static final String OMCHILD_UTILITIES_OPTIMIZE_INDEX_RESPONSE = "optimizeIndexResponse";
	/** Element name of response: removeCategoriesResponse. */
	public static final String OMCHILD_UTILITIES_REMOVE_CATEGORIES_RESPONSE = "removeCategoriesResponse";
	/** Element name of response: setCategories. */
	public static final String OMCHILD_UTILITIES_SET_CATEGORIES_RESPONSE = "setCategoriesResponse";

	/** Namespace URI: SOAP envelope. */
	public static final String QNAME_NS_URI_SOAP_ENVELOPE = "http://www.w3.org/2003/05/soap-envelope";
	/** Namespace Prefix: SOAP envelope. */
	public static final String QNAME_PREFIX_SOAP_ENVELOPE = "soapenv";

	/** Namespace URI: PDR Allies. */
	public static final String QNAME_NS_URI_ALLIES = "http://allies.pdr.bbaw.org";
	/** Namespace Prefix: PDR Allies. */
	public static final String QNAME_PREFIX_ALLIES = "allies";

	private AlliesConstants()
	{ }

	/**
	 * Ordinary key-value pair.
	 * @author Fabian Körner
	 */
	protected static class KeyValuePair
	{
		private String _key;
		private String _value;

		protected KeyValuePair(final String key, final String value)
		{
			_key = key;
			_value = value;
		}

		protected final String getKey()
		{
			return _key;
		}

		protected final String getValue()
		{
			return _value;
		}
	}
}
