/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies.client;


/**
 * PDR ID range of a certain PDR type.
 * @author Fabian Körner
 */
public class IDRange
{
	/** Upper limit of Instance IDs. */
	public static final int MAX_INSTANCE_ID = 999;
	/** Upper limit of project IDs. */
	public static final int MAX_PROJECT_ID = 999;
	/** Upper limit of object IDs. */
	public static final int MAX_OBJECT_ID = 999999999;

	private PDRType _type;
	private int _instance;
	private int _project;
	private int _lowerBound;
	private int _upperBound;

	/**
	 * Constructor with all necessary parameters.
	 * @param type PDR object type.
	 * @param instance ID of PDR instance.
	 * @param project Project ID.
	 * @param lowerBound Lower bound of specified range.
	 * @param upperBound Upper bound of specified range.
	 */
	public IDRange(final PDRType type, final int instance, final int project, final int lowerBound, final int upperBound)
	{
		_type = type;
		_instance = instance;
		_project = project;
		_lowerBound = lowerBound;
		_upperBound = upperBound;
	}

	/**
	 * Returns PDR Type of objects in range.
	 * @return PDR Type.
	 */
	public final PDRType getType()
	{
		return _type;
	}

	/**
	 * Returns PDR instance ID of objects in range.
	 * @return PDR instance ID.
	 */
	public final int getInstance()
	{
		return _instance;
	}

	/**
	 * Returns PDR project ID of objects in range.
	 * @return PDR project ID.
	 */
	public final int getProject()
	{
		return _project;
	}

	/**
	 * Returns the lower bound of object IDs in range.
	 * @return Lower bound.
	 */
	public final int getLowerBound()
	{
		return _lowerBound;
	}

	/**
	 * Returns the upper bound of object IDs in range.
	 * @return Upper bound.
	 */
	public final int getUpperBound()
	{
		return _upperBound;
	}

	/**
	 * @see java.lang.Object#toString()
	 * @return Object's string representation.
	 */
	@Override
	public final String toString()
	{
		StringBuilder sb = new StringBuilder();
		sb.append("IDRange[");
		sb.append(_type.toString());
		sb.append(',');
		sb.append(Integer.toString(_instance));
		sb.append(',');
		sb.append(Integer.toString(_project));
		sb.append(',');
		sb.append(Integer.toString(_lowerBound));
		sb.append('-');
		sb.append(Integer.toString(_upperBound));
		sb.append(']');
		return sb.toString();
	}
}
