/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.util.List;

import org.bbaw.pdr.allies.client.Configuration;
import org.bbaw.pdr.allies.client.Utilities;
import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestCategories
{

	private static final org.bbaw.pdr.allies.client.tests.Configuration TEST_CONFIG = new ConfigurationFromFile();

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(TEST_CONFIG.getAxis2BaseUri());
		Configuration.getInstance().setPDRUser("pdrUo.001.002.000000001", TEST_CONFIG.getPDRUserPW(1, 2, 1));
		Utilities.setCategories("Test getCategories method.", "TEST_GET");
		Utilities.setCategories("Test removeCategories method.", "TEST_REMOVE");
	}

	/**
	 * @throws Exception Exception.
	 */
	@AfterClass
	public static void tearDown() throws Exception
	{
		Utilities.removeCategories("TEST_GET");
		Utilities.removeCategories("TEST_SET");
		Utilities.removeCategories("TEST_PROVIDER");
		Utilities.removeCategories("TEST_REMOVE");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetCategories() throws Exception
	{
		String expected = "Test getCategories method.";
		String actual = Utilities.getCategories("TEST_GET");
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testSetCategories() throws Exception
	{
		String provider = "TEST_SET";
		String expected = "Test setCategories method.";
		Utilities.setCategories(expected, provider);
		String actual = Utilities.getCategories(provider);
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetCategoryProvidersWithKnownProvider() throws Exception
	{
		String provider = "TEST_PROVIDER";
		Utilities.setCategories("Test getCategoryProviders.", provider);
		List<String> providers = Utilities.getCategoryProviders();
		assertTrue(providers.contains(provider));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetCategoryProvidersWithUnknownProvider() throws Exception
	{
		List<String> providers = Utilities.getCategoryProviders();
		assertFalse(providers.contains("TEST_UNKNOWN_PROVIDER"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testRemoveCategories() throws Exception
	{
		String provider = "TEST_REMOVE";
		List<String> providers = Utilities.getCategoryProviders();
		assertTrue(providers.contains(provider));
		Utilities.removeCategories(provider);
		providers = Utilities.getCategoryProviders();
		assertFalse(providers.contains(provider));
	}
}
