/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertEquals;

import java.net.URL;

import org.apache.commons.codec.digest.DigestUtils;
import org.bbaw.pdr.allies.client.Tools;
import org.bbaw.pdr.allies.client.Configuration;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestConfiguration
{

	private static final String AXIS2_BASE_URL = "https://localhost/axis2";
	private static final String USER_ID = "pdrUo.001.001.000000001";
	private static final String USER_PASSWORD = "testballon";

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetAxis2BaseURLDirectly() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(AXIS2_BASE_URL);
		String expected = AXIS2_BASE_URL;
		String actual = Configuration.getInstance().getAxis2BaseURL();

		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetAxis2BaseURLViaTools() throws Exception
	{
		Tools.setAxis2Base(new URL(AXIS2_BASE_URL));
		String expected = AXIS2_BASE_URL;
		String actual = Configuration.getInstance().getAxis2BaseURL();

		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetPDRUserID() throws Exception
	{
		Configuration.getInstance().setPDRUser(USER_ID, USER_PASSWORD);
		String expected = USER_ID;
		String actual = Configuration.getInstance().getPDRUserID();
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetMD5Password() throws Exception
	{
		Configuration.getInstance().setPDRUser(USER_ID, USER_PASSWORD);
		String expected = DigestUtils.md5Hex(USER_PASSWORD);
		String actual = Configuration.getInstance().getMD5Password();
		assertEquals(expected, actual);
	}
}
