/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertEquals;

import java.util.Vector;

import org.bbaw.pdr.allies.client.Tools;
import org.bbaw.pdr.allies.client.Configuration;
import org.bbaw.pdr.allies.client.DataParts;
import org.bbaw.pdr.allies.client.PDRType;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestDataParts
{

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setPDRUser("pdrUo.001.002.000000001", "test1996");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetVersion() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getVersion xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\" />"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetVersion();
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetTime() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getTime xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\" />"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetTime();
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetOccupiedObjectIDRanges() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getOccupiedIDRanges xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<Max>9999999</Max>"
			+ "<Min>1</Min>"
			+ "<Project>2</Project>"
			+ "<Instance>1</Instance>"
			+ "<Type>pdrAo</Type>"
			+ "</axis2ns3:getOccupiedIDRanges>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetOccupiedObjectIDRanges(PDRType.ASPECT, 1, 2, 1, 9999999);
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateSetCategories() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:setCategories xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<Provider>T_E_S_T</Provider>"
			+ "<Categories>Das ist ein simpler Test.</Categories>"
			+ "<Credentials>pdrUo.001.002.000000001#84e92abb5d4b60df3b2835ad569f5aed</Credentials>"
			+ "</axis2ns3:setCategories>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createSetCategories("T_E_S_T", "Das ist ein simpler Test.");
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetCategories() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getCategories xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<Provider>T_E_S_T</Provider>"
			+ "</axis2ns3:getCategories>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetCategories("T_E_S_T");
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetCategoryProviders() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getCategoryProviders xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\" />"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetCategoryProviders();
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetObjects() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getObjects xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<Max>6</Max>"
			+ "<Min>3</Min>"
			+ "<Project>2</Project>"
			+ "<Instance>1</Instance>"
			+ "<Type>pdrAo</Type>"
			+ "<Credentials>pdrUo.001.002.000000001#84e92abb5d4b60df3b2835ad569f5aed</Credentials>"
			+ "</axis2ns3:getObjects>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetObjects(PDRType.ASPECT, 1, 2, 3, 6);
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetProjectSizes() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getProjectSizes xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\" />"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetProjectSizes();
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateRemoveCategories() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:removeCategories xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<Provider>T_E_S_T</Provider>"
			+ "<Credentials>pdrUo.001.002.000000001#84e92abb5d4b60df3b2835ad569f5aed</Credentials>"
			+ "</axis2ns3:removeCategories>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createRemoveCategories("T_E_S_T");
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetModifiedObjects() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getModifiedObjects xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<Timestamp>2012-01-01T12:00:00Z</Timestamp>"
			+ "<Project>2</Project>"
			+ "<Instance>1</Instance>"
			+ "<Credentials>pdrUo.001.002.000000001#84e92abb5d4b60df3b2835ad569f5aed</Credentials>"
			+ "</axis2ns3:getModifiedObjects>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetModifiedObjects(1, 2, "2012-01-01T12:00:00Z");
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateIngestObjects() throws Exception
	{
		Vector<String> objects = new Vector<String>();
		objects.add("test object 1");
		objects.add("test object 2");
		objects.add("test object 3");
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:ingestObjects xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<Object0>" + Tools.cloak("test object 1") + "</Object0>"
			+ "<Object1>" + Tools.cloak("test object 2") + "</Object1>"
			+ "<Object2>" + Tools.cloak("test object 3") + "</Object2>"
			+ "<Project>2</Project>"
			+ "<Instance>1</Instance>"
			+ "<Credentials>pdrUo.001.002.000000001#84e92abb5d4b60df3b2835ad569f5aed</Credentials>"
			+ "</axis2ns3:ingestObjects>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createIngestObjects(1, 2, objects);
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateModifyObjects() throws Exception
	{
		Vector<String> objects = new Vector<String>();
		objects.add("test object 1");
		objects.add("test object 2");
		objects.add("test object 3");
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:modifyObjects xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<Object0>" + Tools.cloak("test object 1") + "</Object0>"
			+ "<Object1>" + Tools.cloak("test object 2") + "</Object1>"
			+ "<Object2>" + Tools.cloak("test object 3") + "</Object2>"
			+ "<Force>true</Force>"
			+ "<Project>2</Project>"
			+ "<Instance>1</Instance>"
			+ "<Credentials>pdrUo.001.002.000000001#84e92abb5d4b60df3b2835ad569f5aed</Credentials>"
			+ "</axis2ns3:modifyObjects>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createModifyObjects(1, 2, objects, true);
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateGetUserID() throws Exception
	{
		String expected =
			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
			+ "<soapenv:Envelope xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\">"
			+ "<soapenv:Body>"
			+ "<axis2ns3:getUserID xmlns:axis2ns3=\"http://allies.pdr.bbaw.org\">"
			+ "<User>test</User>"
			+ "<Project>3</Project>"
			+ "</axis2ns3:getUserID>"
			+ "</soapenv:Body>"
			+ "</soapenv:Envelope>";
		String actual = DataParts.createGetUserID("test", 3);
		assertEquals(expected, actual);
	}
}
