/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertEquals;

import java.util.List;

import org.bbaw.pdr.allies.client.Configuration;
import org.bbaw.pdr.allies.client.PDRType;
import org.bbaw.pdr.allies.client.Utilities;
import org.bbaw.pdr.allies.error.PDRStorageException;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestGetObjects
{

	private static final org.bbaw.pdr.allies.client.tests.Configuration TEST_CONFIG = new ConfigurationFromFile();

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(TEST_CONFIG.getAxis2BaseUri());
		Configuration.getInstance().setPDRUser("pdrUo.001.002.000000001", TEST_CONFIG.getPDRUserPW(1, 2, 1));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetObjectsNoAspects() throws Exception
	{
		List<String> actual = Utilities.getObjects(PDRType.ASPECT, 1, 2, 3, 6);
		assertEquals(0, actual.size());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetObjectsNineUsers() throws Exception
	{
		List<String> actual = Utilities.getObjects(PDRType.USER, 1, 2, 1, 9);
		assertEquals(9, actual.size());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = PDRStorageException.class) //FIXME zweckentfremdet
	public final void testGetObjectsHundredAspects() throws Exception
	{
		List<String> actual = Utilities.getObjects(PDRType.ASPECT, 1, 5, 11, 110);
		assertEquals(100, actual.size());
	}

}
