package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertEquals;

import java.net.URI;
import java.util.List;
import java.util.Vector;

import org.apache.solr.client.solrj.SolrServer;
import org.apache.solr.client.solrj.impl.HttpSolrServer;
import org.bbaw.pdr.allies.client.Configuration;
import org.bbaw.pdr.allies.client.Repository;
import org.bbaw.pdr.allies.error.PDRAlliesClientException;
import org.bbaw.pdr.padre.PadreConfiguration;
import org.bbaw.pdr.padre.client.PadreClient;
import org.bbaw.pdr.solr.SolrConfiguration;
import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestGetUserID
{

	private static final org.bbaw.pdr.allies.client.tests.Configuration TEST_CONFIG = new ConfigurationFromFile();
	private static PadreClient _padreClient;
	private static SolrServer _solrServer;

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(TEST_CONFIG.getAxis2BaseUri());
		Configuration.getInstance().setPDRUser("pdrUo.001.002.000000001", TEST_CONFIG.getPDRUserPW(1, 2, 1));

		PadreConfiguration.getInstance().setCredentials(URI.create(TEST_CONFIG.getPadreUri()), TEST_CONFIG.getPadreUsername(), TEST_CONFIG.getPadrePassword());
		SolrConfiguration.getInstance().setBaseURI(URI.create(TEST_CONFIG.getSolrUri()));
		_solrServer = SolrConfiguration.getInstance().getSolrServer();
		_padreClient = PadreConfiguration.getInstance().getPadreClient();
		_padreClient.createStore("321");

		List<String> users = new Vector<String>();
		users.add(new User("pdrUo.001.801.000000001", "pdrAdmin", "pdrAdmin", "admin", "user").toXML());
		users.add(new User("pdrUo.001.801.000000002", "admin", "admin", "user").toXML());
		users.add(new User("pdrUo.001.801.000000003", "user", "user").toXML());
		users.add(new User("pdrUo.001.801.000000004", "guest", "guest").toXML());
		users.add(new User("pdrUo.001.801.000000005", "computer", "dummy").toXML());
		users.add(new User("pdrUo.001.801.000000006", "dummy", "dummy").toXML());
		users.add(new User("pdrUo.001.801.000000007", "dummy", "dummy").toXML());
		users.add(new User("pdrUo.001.801.000000008", "dummy", "dummy").toXML());
		users.add(new User("pdrUo.001.801.000000009", "dummy", "dummy").toXML());
		users.add(new User("pdrUo.001.801.000000010", "max_mustermann", "user").toXML());
		Repository.modifyObjects(1, 801, users, true);
	}

	/**
	 * @throws Exception Exception.
	 */
	@AfterClass
	public static void tearDown() throws Exception
	{
		_padreClient.deleteStore("321");
		_solrServer.deleteByQuery("id.project:801");
		((HttpSolrServer) _solrServer).shutdown();
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 2000)
	public final void testOK1() throws Exception
	{
		assertEquals("pdrUo.001.801.000000001", Repository.getUserID("pdrAdmin", 801));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 2000)
	public final void testOK4() throws Exception
	{
		assertEquals("pdrUo.001.801.000000004", Repository.getUserID("guest", 801));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 2000)
	public final void testOK2() throws Exception
	{
		assertEquals("pdrUo.001.801.000000002", Repository.getUserID("admin", 801));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 2000)
	public final void testOK10() throws Exception
	{
		assertEquals("pdrUo.001.801.000000010", Repository.getUserID("max_mustermann", 801));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test(expected = PDRAlliesClientException.class, timeout = 2000)
	public final void testAmbigousName() throws Exception
	{
		Repository.getUserID("dummy", 801);
	}

	/**
	 * @author Fabian Körner
	 */
	static class User
	{
		private String _id;
		private String _username;
		private List<String> _roles;

		User(final String id, final String username, final String... roles)
		{
			_id = id;
			_username = username;
			_roles = new Vector<String>();
			for (String role : roles)
			{
				_roles.add(role);
			}
		}

		String toXML()
		{
			StringBuilder sb = new StringBuilder();
			sb.append("<user xmlns=\"http://pdr.bbaw.de/namespaces/uodl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" id=\"");
			sb.append(_id);
			sb.append("\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/uodl/ http://pdr.bbaw.de/schema/uodl.xsd\"><record><revision authority=\"pdrUo.001"
					+ ".001.000000001\" ref=\"0\" timestamp=\"2014-01-13T11:00:00\"/></record><authentication password=\"pdrrdp\" username=\"");
			sb.append(_username);
			sb.append("\"><roles>");
			for (String role : _roles)
			{
				sb.append("<role>");
				sb.append(role);
				sb.append("</role>");
			}
			sb.append("</roles></authentication></user>");
			return sb.toString();
		}
	}

}
