package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertEquals;

import java.net.URI;
import java.util.List;
import java.util.Vector;

import org.apache.solr.client.solrj.SolrServer;
import org.apache.solr.client.solrj.impl.HttpSolrServer;
import org.bbaw.pdr.allies.client.Configuration;
import org.bbaw.pdr.allies.client.IDRange;
import org.bbaw.pdr.allies.client.PDRType;
import org.bbaw.pdr.allies.client.Repository;
import org.bbaw.pdr.allies.client.Utilities;
import org.bbaw.pdr.padre.PadreConfiguration;
import org.bbaw.pdr.padre.client.PadreClient;
import org.bbaw.pdr.solr.SolrConfiguration;
import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestModifyObjects
{

	private static final org.bbaw.pdr.allies.client.tests.Configuration TEST_CONFIG = new ConfigurationFromFile();
	private static PadreClient _padreClient;
	private static SolrServer _solrServer;

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(TEST_CONFIG.getAxis2BaseUri());
		Configuration.getInstance().setPDRUser("pdrUo.001.002.000000001", TEST_CONFIG.getPDRUserPW(1, 2, 1));
		PadreConfiguration.getInstance().setCredentials(URI.create(TEST_CONFIG.getPadreUri()), TEST_CONFIG.getPadreUsername(), TEST_CONFIG.getPadrePassword());
		SolrConfiguration.getInstance().setBaseURI(URI.create(TEST_CONFIG.getSolrUri()));
		_solrServer = SolrConfiguration.getInstance().getSolrServer();
		_padreClient = PadreConfiguration.getInstance().getPadreClient();
		_padreClient.createStore("321");

		List<String> objects = new Vector<String>();
		objects.add(TestModifyObjects.createNewPersonObject("pdrPo.001.801.100000001"));
		objects.add(TestModifyObjects.createNewPersonObject("pdrPo.001.801.100000002"));
		objects.add(TestModifyObjects.createNewPersonObject("pdrPo.001.801.100000003"));
		objects.add(TestModifyObjects.createNewPersonObject("pdrPo.001.801.100000004"));
		objects.add(TestModifyObjects.createNewPersonObject("pdrPo.001.801.100000005"));
		org.bbaw.pdr.utils.Repository.ingestObjects(1, 801, objects);

		TestModifyObjects.setUpInvestigatorSyncronisation();
	}

	/**
	 * @throws Exception Exception.
	 */
	@AfterClass
	public static void tearDown() throws Exception
	{
		_padreClient.deleteStore("321");
		_solrServer.deleteByQuery("id.project:801");

		TestModifyObjects.tearDownInvestigatorSyncronisation();

		((HttpSolrServer) _solrServer).shutdown();
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 3000)
	public final void testModifyObjects() throws Exception
	{
		Thread.sleep(1000L);
		List<IDRange> ranges = Utilities.getOccupiedObjectIDRanges(PDRType.PERSON, 1, 801, 1, 10);
		assertEquals(1, ranges.size());
		assertEquals(1, ranges.get(0).getLowerBound());
		assertEquals(5, ranges.get(0).getUpperBound());

		String timestamp = Repository.getTime();

		List<String> modifiedObjects = new Vector<String>();
		modifiedObjects.add(TestModifyObjects.createModifiedPersonObject("pdrPo.001.801.000000002"));
		modifiedObjects.add(TestModifyObjects.createModifiedPersonObject("pdrPo.001.801.000000003"));
		Repository.modifyObjects(1, 801, modifiedObjects, false);

		List<String> result = Repository.getModifiedObjects(1, 801, timestamp);
		assertEquals(2, result.size());
	}

	private static String createNewPersonObject(final String id)
	{
		return new String("<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""
				+ " xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"" + id + "\">"
				+ "<record><revision ref=\"0\" timestamp=\"2012-11-30T04:48:08\" authority=\"pdrUo.002.762.000000002\"/></record></person>");
	}

	private static String createModifiedPersonObject(final String id)
	{
		return new String("<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""
				+ " xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"" + id + "\">"
				+ "<record><revision ref=\"0\" timestamp=\"2012-11-30T04:48:08\" authority=\"pdrUo.002.762.000000002\"/>"
				+ "<revision ref=\"1\" timestamp=\"2012-11-30T04:50:08\" authority=\"pdrUo.002.762.000000002\"/></record></person>");
	}

	private static void setUpInvestigatorSyncronisation() throws Exception
	{
		_padreClient.createStore("322");
		List<String> objects = new Vector<String>();
		objects.add(TestModifyObjects.createNewPersonWithoutGND());
		org.bbaw.pdr.utils.Repository.ingestObjects(1, 802, objects);
	}

	private static void tearDownInvestigatorSyncronisation() throws Exception
	{
		_padreClient.deleteStore("322");
		_solrServer.deleteByQuery("id.project:802");
	}

	private static String createNewPersonWithoutGND()
	{
		return "<person xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns=\"http://pdr.bbaw.de/namespaces/podl/\""
				+ " xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdrdev.bbaw.de/schema/podl.xsd\""
				+ " id=\"pdrPo.001.802.100000023\">"
				+ "<record>"
				+ "<revision ref=\"0\" timestamp=\"2011-04-15T10:44:41\" authority=\"pdrUo.001.802.000000005\"/>"
				+ "</record>"
				+ "<identifiers>"
				+ "<identifier provider=\"BK_STADTPLAN\" quality=\"certain\" authority=\"pdrUo.001.802.000000005\">person_23</identifier>"
				+ "</identifiers>"
				+ "</person>";
	}

	private static String createModifiedPersonWithGND()
	{
		return "<person xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns=\"http://pdr.bbaw.de/namespaces/podl/\""
				+ " xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdrdev.bbaw.de/schema/podl.xsd\""
				+ " id=\"pdrPo.001.802.000000001\">"
				+ "<record>"
				+ "<revision ref=\"0\" timestamp=\"2011-04-15T10:44:41\" authority=\"pdrUo.001.802.000000005\"/>"
				+ "<revision timestamp=\"2013-10-10T16:24:05\" authority=\"pdrUo.001.802.000000005\" ref=\"1\"/>"
				+ "</record>"
				+ "<identifiers>"
				+ "<identifier provider=\"BK_STADTPLAN\" quality=\"certain\" authority=\"pdrUo.001.802.000000005\">person_23</identifier>"
				+ "<identifier provider=\"GND\" quality=\"certain\" authority=\"pdrUo.001.802.000000005\">118672576</identifier>"
				+ "</identifiers>"
				+ "</person>";
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 3000)
	public final void testInvestigatorSyncronisation() throws Exception
	{
		Thread.sleep(1000L);
		List<IDRange> ranges = Utilities.getOccupiedObjectIDRanges(PDRType.PERSON, 1, 802, 1, 10);
		assertEquals(1, ranges.size());
		assertEquals(1, ranges.get(0).getLowerBound());
		assertEquals(1, ranges.get(0).getUpperBound());

		List<String> modifiedObjects = new Vector<String>();
		modifiedObjects.add(TestModifyObjects.createModifiedPersonWithGND());
		Repository.modifyObjects(1, 802, modifiedObjects, true);

		Vector<String> objects = Utilities.getObjects(PDRType.PERSON, 1, 802, 1, 10);
		assertEquals(1, objects.size());
		assertEquals(TestModifyObjects.createModifiedPersonWithGND(), objects.get(0));
	}
}
