/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertEquals;

import java.util.List;

import org.bbaw.pdr.allies.client.Configuration;
import org.bbaw.pdr.allies.client.IDRange;
import org.bbaw.pdr.allies.client.PDRType;
import org.bbaw.pdr.allies.client.Utilities;
import org.bbaw.pdr.allies.error.PDRAlliesClientException;
import org.bbaw.pdr.allies.error.PDRStorageException;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestOccupiedIDRanges
{

	private static final org.bbaw.pdr.allies.client.tests.Configuration TEST_CONFIG = new ConfigurationFromFile();

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(TEST_CONFIG.getAxis2BaseUri());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetOccupiedObjectIDRangesAllUsers() throws Exception
	{
		List<IDRange> ranges = Utilities.getOccupiedObjectIDRanges(PDRType.USER, 1, 2, 1, 99999);
		assertEquals(1, ranges.size());
		IDRange range = ranges.get(0);
		assertEquals(1, range.getLowerBound());
		assertEquals(9, range.getUpperBound());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetOccupiedObjectIDRangesSomeUsers() throws Exception
	{
		List<IDRange> ranges = Utilities.getOccupiedObjectIDRanges(PDRType.USER, 1, 2, 4, 8);
		assertEquals(1, ranges.size());
		IDRange range = ranges.get(0);
		assertEquals(4, range.getLowerBound());
		assertEquals(8, range.getUpperBound());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetOccupiedObjectIDRangesSingleUser() throws Exception
	{
		List<IDRange> ranges = Utilities.getOccupiedObjectIDRanges(PDRType.USER, 1, 2, 5, 5);
		assertEquals(1, ranges.size());
		IDRange range = ranges.get(0);
		assertEquals(5, range.getLowerBound());
		assertEquals(5, range.getUpperBound());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetOccupiedObjectIDRangesNoAspects() throws Exception
	{
		List<IDRange> ranges = Utilities.getOccupiedObjectIDRanges(PDRType.ASPECT, 1, 2, 1, 99999);
		assertEquals(0, ranges.size());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = PDRStorageException.class) // FIXME zweckentfremdet
	public final void testGetOccupiedObjectIDRanges3() throws Exception
	{
		List<IDRange> ranges = Utilities.getOccupiedObjectIDRanges(PDRType.ASPECT, 1, 5, 1, 99999);
		assertEquals(1, ranges.size());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test(expected = PDRAlliesClientException.class)
	public final void testGetOccupiedObjectIDRangesUnknownProject() throws Exception
	{
		Utilities.getOccupiedObjectIDRanges(PDRType.ASPECT, 1, 932, 1, 99999);
	}
}
