package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.net.URI;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.http.HttpStatus;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.util.EntityUtils;
import org.bbaw.pdr.allies.client.Tools;
import org.bbaw.pdr.allies.client.Configuration;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestOptimizeIndex
{

	private static final org.bbaw.pdr.allies.client.tests.Configuration TEST_CONFIG = new ConfigurationFromFile();

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(TEST_CONFIG.getAxis2BaseUri());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 60000)
	public final void testOptimizeIndex() throws Exception
	{
		CloseableHttpClient client = Tools.buildHttpClient();
		URI uri = URI.create(Configuration.getInstance().getAxis2BaseURL().toString() + "/services/Utilities/optimizeIndex");
		HttpGet get = new HttpGet(uri);
		CloseableHttpResponse response = client.execute(get);
		if (HttpStatus.SC_OK == response.getStatusLine().getStatusCode())
		{
			String content = EntityUtils.toString(response.getEntity(), "UTF-8");
			Pattern pattern = Pattern.compile("<allies:optimizeIndexResponse.+?><allies:Timestamp>(.+?)</allies:Timestamp></allies:optimizeIndexResponse>");
			Matcher matcher = pattern.matcher(content);
			if (matcher.find())
			{
				String timestamp = Tools.uncloak(matcher.group(1));
				Pattern timestampPattern = Pattern.compile("^\\d{2}[.]\\d{2}[.]\\d{4}\\s\\d{2}:\\d{2}:\\d{2}$");
				Matcher pdrMatcher = timestampPattern.matcher(timestamp);
				if (!pdrMatcher.find())
				{
					fail("expected pdr object pattern not found");
				}
			}
			else
			{
				fail("expected allies response pattern not found");
			}
		}
		else
		{
			fail(response.getStatusLine().getStatusCode() + ": " + response.getStatusLine().getReasonPhrase());
		}
		response.close();
		client.close();
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 60000)
	public final void testSolrSelect() throws Exception
	{
		CloseableHttpResponse response = TestOptimizeIndex.getHttpGetResponse(
				"/services/Utilities/isIndexOptimized?Timestamp=" + Tools.cloak("01.01.2000 12:34:56"));
		if (HttpStatus.SC_OK == response.getStatusLine().getStatusCode())
		{
			String content = EntityUtils.toString(response.getEntity(), "UTF-8");
			Pattern pattern = Pattern.compile("<allies:isIndexOptimizedResponse.+?><allies:Value>(.+?)</allies:Value></allies:isIndexOptimizedResponse>");
			Matcher matcher = pattern.matcher(content);
			if (matcher.find())
			{
				String value = Tools.uncloak(matcher.group(1));
				assertTrue(value.equals("true") || value.equals("false"));
			}
			else
			{
				fail("expected allies response pattern not found");
			}
		}
		else
		{
			fail(response.getStatusLine().getStatusCode() + ": " + response.getStatusLine().getReasonPhrase());
		}
	}

	private static CloseableHttpResponse getHttpGetResponse(final String pathAndParameters) throws Exception
	{
		CloseableHttpClient client = Tools.buildHttpClient();
		HttpGet get = new HttpGet(URI.create(Configuration.getInstance().getAxis2BaseURL().toString() + pathAndParameters));
		return client.execute(get);
	}
}
