package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.fail;

import java.net.URI;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.http.HttpStatus;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.util.EntityUtils;
import org.bbaw.pdr.allies.client.Tools;
import org.bbaw.pdr.allies.client.Configuration;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestPITConnector
{

	private static final org.bbaw.pdr.allies.client.tests.Configuration TEST_CONFIG = new ConfigurationFromFile();

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(TEST_CONFIG.getAxis2BaseUri());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 2000)
	public final void testSolrSelect() throws Exception
	{
		CloseableHttpClient client = Tools.buildHttpClient();
		URI uri = URI.create(Configuration.getInstance().getAxis2BaseURL().toString() + "/services/PITConnector/solrSelect?q=*:*");
		HttpGet get = new HttpGet(uri);
		CloseableHttpResponse response = client.execute(get);
		if (HttpStatus.SC_OK == response.getStatusLine().getStatusCode())
		{
			String content = EntityUtils.toString(response.getEntity(), "UTF-8");
			Pattern pattern = Pattern.compile("^<allies:solrSelectResponse.+?><allies:Response>(.+?)</allies:Response></allies:solrSelectResponse>$");
			Matcher matcher = pattern.matcher(content);
			if (matcher.find())
			{
				String solrContent = Tools.uncloak(matcher.group(1));
				Pattern solrPattern = Pattern.compile("^<\\?xml.+?\\?>\\n<response>.+</response>$", Pattern.DOTALL);
				Matcher solrMatcher = solrPattern.matcher(solrContent);
				if (!solrMatcher.find())
				{
					fail("expected solr response pattern not found");
				}
			}
			else
			{
				fail("expected allies response pattern not found");
			}
		}
		else
		{
			fail(response.getStatusLine().getStatusCode() + ": " + response.getStatusLine().getReasonPhrase());
		}
		response.close();
		client.close();
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (timeout = 2000)
	public final void testGetObject() throws Exception
	{
		String pdrID = "pdrUo.001.002.000000001";

		CloseableHttpClient client = Tools.buildHttpClient();
		URI uri = URI.create(Configuration.getInstance().getAxis2BaseURL().toString() + "/services/PITConnector/getObject?Id=" + pdrID);
		HttpGet get = new HttpGet(uri);
		CloseableHttpResponse response = client.execute(get);
		if (HttpStatus.SC_OK == response.getStatusLine().getStatusCode())
		{
			String content = EntityUtils.toString(response.getEntity(), "UTF-8");
			Pattern pattern = Pattern.compile("<allies:getObjectResponse.+?><allies:Object>(.+?)</allies:Object></allies:getObjectResponse>");
			Matcher matcher = pattern.matcher(content);
			if (matcher.find())
			{
				String pdrContent = Tools.uncloak(matcher.group(1));
				Pattern pdrPattern = Pattern.compile("^<user.*?id=[\"]" + pdrID + "[\"].*?>.+</user>$");
				Matcher pdrMatcher = pdrPattern.matcher(pdrContent);
				if (!pdrMatcher.find())
				{
					fail("expected pdr object pattern not found");
				}
			}
			else
			{
				fail("expected allies response pattern not found");
			}
		}
		else
		{
			fail(response.getStatusLine().getStatusCode() + ": " + response.getStatusLine().getReasonPhrase());
		}
		response.close();
		client.close();
	}
}
