/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies.client.tests;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.bbaw.pdr.allies.client.Configuration;
import org.bbaw.pdr.allies.client.Utilities;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestServerVersion
{

	private static final org.bbaw.pdr.allies.client.tests.Configuration TEST_CONFIG = new ConfigurationFromFile();

	// FIXME keep version number uptodate
	private static final int CURRENT_MAJOR_VERSION = 1;
	private static final int CURRENT_MINOR_VERSION = 1;
	private static final int CURRENT_FIXED_VERSION = 0;

	/**
	 * @throws Exception Exception.
	 */
	@BeforeClass
	public static void setUp() throws Exception
	{
		Configuration.getInstance().setAxis2BaseURL(TEST_CONFIG.getAxis2BaseUri());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testGetPDRAlliesVersionResponse()
	throws Exception
	{
		String version = String.format("PDR Allies v%d.%d.%d",
				CURRENT_MAJOR_VERSION, CURRENT_MINOR_VERSION, CURRENT_FIXED_VERSION);
		String actual = Utilities.getServerVersion();
		assertEquals(version, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCheckCurrentServerVersion() throws Exception
	{
		String version = String.format("PDR Allies v%d.%d.%d",
				CURRENT_MAJOR_VERSION, CURRENT_MINOR_VERSION, CURRENT_FIXED_VERSION);

		assertTrue(Utilities.checkServerVersion(version));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCheckNextMajorServerVersion() throws Exception
	{
		String version = String.format("PDR Allies v%d.%d.%d",
				TestServerVersion.getNextVersionPartValue(CURRENT_MAJOR_VERSION), CURRENT_MINOR_VERSION, CURRENT_FIXED_VERSION);

		assertFalse(Utilities.checkServerVersion(version));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCheckNextMinorServerVersion() throws Exception
	{
		String version = String.format("PDR Allies v%d.%d.%d",
				CURRENT_MAJOR_VERSION, TestServerVersion.getNextVersionPartValue(CURRENT_MINOR_VERSION), CURRENT_FIXED_VERSION);

		assertFalse(Utilities.checkServerVersion(version));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCheckNextFixedServerVersion() throws Exception
	{
		String version = String.format("PDR Allies v%d.%d.%d",
				CURRENT_MAJOR_VERSION, CURRENT_MINOR_VERSION, TestServerVersion.getNextVersionPartValue(CURRENT_FIXED_VERSION));

		assertFalse(Utilities.checkServerVersion(version));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCheckLastMajorServerVersion() throws Exception
	{
		String version = String.format("PDR Allies v%d.%d.%d",
				TestServerVersion.getLastVersionPartValue(CURRENT_MAJOR_VERSION), CURRENT_MINOR_VERSION, CURRENT_FIXED_VERSION);

		assertTrue(Utilities.checkServerVersion(version));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCheckLastMinorServerVersion() throws Exception
	{
		String version = String.format("PDR Allies v%d.%d.%d",
				CURRENT_MAJOR_VERSION, TestServerVersion.getLastVersionPartValue(CURRENT_MINOR_VERSION), CURRENT_FIXED_VERSION);

		assertTrue(Utilities.checkServerVersion(version));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCheckLastFixedServerVersion() throws Exception
	{
		String version = String.format("PDR Allies v%d.%d.%d",
				CURRENT_MAJOR_VERSION, CURRENT_MINOR_VERSION, TestServerVersion.getLastVersionPartValue(CURRENT_FIXED_VERSION));

		assertTrue(Utilities.checkServerVersion(version));
	}

	private static int getNextVersionPartValue(final int currentValue)
	{
		if (currentValue < 0)
		{
			return 0;
		}
		else if (currentValue >= 99)
		{
			return 99;
		}
		else
		{
			return currentValue + 1;
		}
	}

	private static int getLastVersionPartValue(final int currentValue)
	{
		if (currentValue <= 0)
		{
			return 0;
		}
		else if (currentValue > 99)
		{
			return 99;
		}
		else
		{
			return currentValue - 1;
		}
	}
}
