/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-Allies.
 *
 *	PDR-Allies is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-Allies is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-Allies.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.allies.tests;

import static org.junit.Assert.assertEquals;

import org.bbaw.pdr.allies.Credentials;
import org.bbaw.pdr.allies.error.InvalidCredentialsException;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestCredentials
{

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testConstructor() throws Exception
	{
		String expectedUserID = "pdrUo.001.001.000000001";
		String expectedHash = "098f6bcd4621d373cade4e832627b4f6";
		String expectedCombined = "pdrUo.001.001.000000001#098f6bcd4621d373cade4e832627b4f6";
		Credentials credentials = new Credentials("pdrUo.001.001.000000001", "098f6bcd4621d373cade4e832627b4f6");

		assertEquals(expectedUserID, credentials.getUserID());
		assertEquals(expectedHash, credentials.getMD5Password());
		assertEquals(expectedCombined, credentials.getCredentials());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testConstructorWithInvalidIDType() throws Exception
	{
		new Credentials("pdrPo.001.001.000000001", "098f6bcd4621d373cade4e832627b4f6");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testConstructorWithInvalidIDInstance() throws Exception
	{
		new Credentials("pdrUo.00h.001.000000001", "098f6bcd4621d373cade4e832627b4f6");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testConstructorWithInvalidIDProject() throws Exception
	{
		new Credentials("pdrUo.001.00.000000001", "098f6bcd4621d373cade4e832627b4f6");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testConstructorWithInvalidIDObject() throws Exception
	{
		new Credentials("pdrUo.001.001.00000001a", "098f6bcd4621d373cade4e832627b4f6");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testConstructorWithInvalidHash() throws Exception
	{
		new Credentials("pdrUo.001.001.000000001", "098f6bcd4621d373cade4e832627b4fz");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCombinedConstructor() throws Exception
	{
		String expectedUserID = "pdrUo.001.001.000000001";
		String expectedHash = "098f6bcd4621d373cade4e832627b4f6";
		String expectedCombined = "pdrUo.001.001.000000001#098f6bcd4621d373cade4e832627b4f6";
		Credentials credentials = new Credentials("pdrUo.001.001.000000001#098f6bcd4621d373cade4e832627b4f6");

		assertEquals(expectedUserID, credentials.getUserID());
		assertEquals(expectedHash, credentials.getMD5Password());
		assertEquals(expectedCombined, credentials.getCredentials());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testCombinedConstructorWithInvalidIDType() throws Exception
	{
		new Credentials("pdrUoo.001.001.000000001#098f6bcd4621d373cade4e832627b4f6");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testCombinedConstructorWithInvalidIDInstance() throws Exception
	{
		new Credentials("pdrUo.000.001.000000001#098f6bcd4621d373cade4e832627b4f6");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testCombinedConstructorWithInvalidIDProject() throws Exception
	{
		new Credentials("pdrUo.001.000.000000001#098f6bcd4621d373cade4e832627b4f6");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testCombinedConstructorWithInvalidIDObject() throws Exception
	{
		new Credentials("pdrUo.001.001.000000000#098f6bcd4621d373cade4e832627b4f6");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testCombinedConstructorWithInvalidHash() throws Exception
	{
		new Credentials("pdrUo.001.001.000000001#098f6bcd4621d373cade4e832627b4f");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = InvalidCredentialsException.class)
	public final void testCombinedConstructorWithSeparator() throws Exception
	{
		new Credentials("pdrUo.001.001.000000001;098f6bcd4621d373cade4e832627b4f6");
	}
}
