/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;

import java.net.URI;

import org.bbaw.pdr.padre.client.PadreClient;
import org.bbaw.pdr.padre.client.PadreClientException;

/**
 * Contains information about access to our PaDRe interface.
 * @author Fabian Körner
 */
public final class PadreConfiguration
{

	private PadreClient _padreClient = null;

	private static final PadreConfiguration INSTANCE = new PadreConfiguration();

	private PadreConfiguration()
	{
	}

	/**
	 * Singleton: returns unique instance.
	 * @return Unique instance.
	 */
	public static PadreConfiguration getInstance()
	{
		return INSTANCE;
	}

	/**
	 * Sets credentials for any access to PaDRe.
	 * @param baseURI Base URI of PaDRe server.
	 * @param username Username for communication with PaDRe server.
	 * @param password Password for communication with PaDRe server.
	 * @throws PadreClientException Error during initialisation of PaDRe client.
	 */
	public void setCredentials(final URI baseURI, final String username, final String password) throws PadreClientException
	{
		_padreClient = new PadreClient(baseURI, username, password);
	}

	/**
	 * Returns a client for communication the the configured PaDRe server.
	 * @return PaDRe client.
	 * @throws PadreClientException PaDRe client not yet configured.
	 */
	public PadreClient getPadreClient() throws PadreClientException
	{
		if (null == _padreClient)
		{
			throw new PadreClientException("PaDRe client not yet configured");
		}
		else
		{
			return _padreClient;
		}
	}
}
