/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;

import org.bbaw.pdr.utils.Identifier;

/**
 * Create a project in the repository.
 * @author Fabian Körner
 */
public final class PadreCreateProject extends AbstractPadreCommand<Object>
{

	private int _project;

	/**
	 * Creates a PaDRe store for given project id.
	 * @param project Project for which to create a store.
	 * @throws PadreCommandException Could not create a store.
	 */
	public PadreCreateProject(final int project) throws PadreCommandException
	{
		super();
		_project = project;
	}

	/**
	 * @see org.bbaw.pdr.padre.AbstractPadreCommand#execute()
	 * @return Null.
	 * @throws PadreCommandException Could not successfully execute PaDRe command.
	 */
	@Override
	public Object execute() throws PadreCommandException
	{
		try
		{
			String padreStoreID = Identifier.intToHexString(_project, 3);

			super.getPadreClient().createStore(padreStoreID);
			return null;
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
	}
}
