/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;


/**
 * Checks PaDRe's availability.
 * @author Fabian Körner
 */
public final class PadrePing extends AbstractPadreCommand<Object>
{

	/**
	 * Checks PaDRe's availability.
	 * @throws PadreCommandException Ping failed.
	 */
	public PadrePing() throws PadreCommandException
	{
		super();
	}

	/**
	 * @see org.bbaw.pdr.padre.AbstractPadreCommand#execute()
	 * @return Null.
	 * @throws PadreCommandException Could not successfully execute PaDRe command.
	 */
	@Override
	public Object execute() throws PadreCommandException
	{
		try
		{
			boolean success = super.getPadreClient().ping();
			if (!success)
			{
				throw new PadreCommandException("unable to ping PaDRe");
			}
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
		return null;
	}
}
