/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;

import java.util.List;
import java.util.Vector;

import org.bbaw.pdr.padre.request.PadreID;
import org.bbaw.pdr.utils.Identifier;

/**
 * Deletes a single PDR object from PaDRe.
 * @author Fabian Körner
 */
public final class PadreSingleDelete extends AbstractPadreCommand<Object>
{

	private Identifier _identifier;

	/**
	 * Deletes the PDR object with the given ID from PaDRe.
	 * @param identifier Identifier of object which will be deleted.
	 * @throws PadreCommandException Could not delete object.
	 */
	public PadreSingleDelete(final String identifier) throws PadreCommandException
	{
		super();
		try
		{
			_identifier = new Identifier(identifier);
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
	}

	/**
	 * @see org.bbaw.pdr.padre.AbstractPadreCommand#execute()
	 * @return Null.
	 * @throws PadreCommandException Could not successfully execute PaDRe command.
	 */
	@Override
	public Object execute() throws PadreCommandException
	{
		try
		{
			List<PadreID> padreIDs = new Vector<PadreID>();
			padreIDs.add(_identifier.toPadreID());
			super.getPadreClient().delete(padreIDs);
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
		return null;
	}
}
