/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;

import java.util.List;
import java.util.Vector;

import org.apache.commons.codec.binary.Base64;
import org.bbaw.pdr.padre.request.PadreID;
import org.bbaw.pdr.padre.request.PadreObject;
import org.bbaw.pdr.utils.Identifier;
import org.bbaw.pdr.utils.PDRObject;

/**
 * Reads a single XML formatted PDR object from PaDRe.
 * @author Fabian Körner
 */
public final class PadreSingleReadXml extends AbstractPadreCommand<PDRObject>
{

	private Identifier _identifier;

	/**
	 * Reads the PDR object with the given Identifier from PaDRe.
	 * @param identifier Identifier of requested object.
	 * @throws PadreCommandException Could not read from PaDRe.
	 */
	public PadreSingleReadXml(final String identifier) throws PadreCommandException
	{
		super();
		try
		{
			_identifier = new Identifier(identifier);
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
	}

	/**
	 * @see org.bbaw.pdr.padre.AbstractPadreCommand#execute()
	 * @return PDR object.
	 * @throws PadreCommandException Could not successfully execute PaDRe command.
	 */
	@Override
	public PDRObject execute() 	throws PadreCommandException
	{
		PDRObject result = null;
		try
		{
			List<PadreID> padreIDs = new Vector<PadreID>();
			padreIDs.add(_identifier.toPadreID());
			List<PadreObject> padreObjects = super.getPadreClient().read(padreIDs);
			String payload = padreObjects.get(0).getPayload();
			byte[] content = Base64.decodeBase64(payload);
			result = new PDRObject(new String(content, "UTF-8"));
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
		return result;
	}
}
