/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre;

import java.util.List;
import java.util.Vector;

import org.bbaw.pdr.padre.request.PadreID;
import org.bbaw.pdr.utils.Identifier;

/**
 * Deletes a span of PDR objects from PaDRe.
 * @author Fabian Körner
 */
public final class PadreSpanDelete extends AbstractPadreCommand<Object>
{

	private Identifier _lowerBound;
	private Identifier _upperBound;

	/**
	 * Deletes all PDR objects within the provided span from PaDRe.
	 * @param minIdentifier Lower bound.
	 * @param maxIdentifier Upper bound.
	 * @throws PadreCommandException Could not delete objects.
	 */
	public PadreSpanDelete(final String minIdentifier, final String maxIdentifier) throws PadreCommandException
	{
		super();
		try
		{
			_lowerBound = new Identifier(minIdentifier);
			_upperBound = new Identifier(maxIdentifier);
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
	}

	/**
	 * @see org.bbaw.pdr.padre.AbstractPadreCommand#execute()
	 * @return Null.
	 * @throws PadreCommandException Could not successfully execute PaDRe command.
	 */
	@Override
	public Object execute() throws PadreCommandException
	{
		try
		{
			PadreID lower = _lowerBound.toPadreID();
			PadreID upper = _upperBound.toPadreID();
			PadreID span = new PadreID(lower.toString() + "-" + upper.toString());
			List<PadreID> padreIDs = new Vector<PadreID>();
			padreIDs.add(span);
			super.getPadreClient().delete(padreIDs);
		}
		catch (Exception cause)
		{
			throw new PadreCommandException(cause);
		}
		return null;
	}
}
