/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import org.apache.http.impl.client.HttpClientBuilder;
import org.apache.solr.client.solrj.SolrServer;

/**
 * @param <T> Expected return type.
 * @author Fabian Körner
 */
public abstract class AbstractSolrCommand<T>
{

	private SolrServer _solrServer;
	private HttpClientBuilder _httpClientBuilder;

	/**
	 * Gets a reference to Solrj's server and provides it to subclassing commands.
	 * @throws SolrCommandException Could not get Solr server.
	 */
	public AbstractSolrCommand() throws SolrCommandException
	{
		_solrServer = SolrConfiguration.getInstance().getSolrServer();
		_httpClientBuilder = HttpClientBuilder.create();
	}

	protected final SolrServer getSolrServer()
	{
		return _solrServer;
	}

	protected final HttpClientBuilder getHttpClientBuilder()
	{
		return _httpClientBuilder;
	}

	/**
	 * Executes the implemented Solr command.
	 * @return Return type depends on implementation.
	 * @throws SolrCommandException Error during command execution.
	 */
	public abstract T execute() throws SolrCommandException;

}
