/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import javax.xml.stream.XMLStreamException;

import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.util.AXIOMUtil;
import org.apache.solr.common.SolrInputDocument;
import org.bbaw.pdr.utils.PDRObject;

/**
 * Creates type-specific input documents for Solr.
 * @author Fabian Körner
 */
public final class SolrInputDocumentFactory
{

	protected static final String LOCAL_NAME_ROOT_ASPECT = "aspect";
	protected static final String LOCAL_NAME_ROOT_PERSON = "person";
	protected static final String LOCAL_NAME_ROOT_REFERENCE = "mods";
	protected static final String LOCAL_NAME_ROOT_USER = "user";

	private SolrInputDocumentFactory()
	{
	}

	/**
	 * Factory method for the creation of Solr input documents.
	 * @param pdrObject PDR object for which the appropriate index document will be created.
	 * @return Solr index document.
	 * @throws SolrCommandException Error identifying the PDR type.
	 * @throws XMLStreamException Error while processing provided XML content.
	 */
	public static SolrInputDocument createSolrInputDocument(final PDRObject pdrObject) throws SolrCommandException, XMLStreamException
	{
		String xmlContent = pdrObject.getXMLContent();

		OMElement root = AXIOMUtil.stringToOM(xmlContent);
		String rootName = root.getLocalName();
		if (LOCAL_NAME_ROOT_ASPECT.equals(rootName))
		{
			return new SolrInputAspect(root);
		}
		else if (LOCAL_NAME_ROOT_PERSON.equals(rootName))
		{
			return new SolrInputPerson(root);
		}
		else if (LOCAL_NAME_ROOT_REFERENCE.equals(rootName))
		{
			return new SolrInputReference(root);
		}
		else if (LOCAL_NAME_ROOT_USER.equals(rootName))
		{
			return new SolrInputUser(root);
		}
		else
		{
			throw new SolrCommandException("unexpected root element: " + rootName);
		}
	}
}
