/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import java.util.Iterator;

import javax.xml.namespace.QName;

import org.apache.axiom.om.OMAttribute;
import org.apache.axiom.om.OMElement;
import org.apache.commons.codec.digest.DigestUtils;

/**
 * Solr input document with index fields specific to users.
 * @author Fabian Körner
 */
public class SolrInputUser extends SolrInputCommon
{

	private static final long serialVersionUID = -3037390933063263956L;

	private QName _qNameAuthenticationElement;
	private QName _qNameRolesElement;
	private QName _qNameRoleElement;

	private QName _qNameUsernameAttribute;
	private QName _qNamePasswordAttribute;

	protected SolrInputUser(final OMElement root)
	{
		super(root);
		this.initQNames();
		this.addSpecificIndexFields();
	}

	private void initQNames()
	{
		_qNameAuthenticationElement = super.createQNameOfElement("authentication");
		_qNameRolesElement = super.createQNameOfElement("roles");
		_qNameRoleElement = super.createQNameOfElement("role");

		_qNameUsernameAttribute = super.createQNameOfAttribute("username");
		_qNamePasswordAttribute = super.createQNameOfAttribute("password");
	}

	private void addSpecificIndexFields()
	{
		OMElement authenticationElement = super.getRoot().getFirstChildWithName(_qNameAuthenticationElement);

		OMAttribute usernameAttribute = authenticationElement.getAttribute(_qNameUsernameAttribute);
		OMAttribute passwordAttribute = authenticationElement.getAttribute(_qNamePasswordAttribute);

		addField("user.username", usernameAttribute.getAttributeValue());
		addField("user.password", DigestUtils.md5Hex(passwordAttribute.getAttributeValue()));

		OMElement rolesElement = authenticationElement.getFirstChildWithName(_qNameRolesElement);
		Iterator<?> roles = rolesElement.getChildrenWithName(_qNameRoleElement);
		OMElement role;
		while (roles.hasNext())
		{
			role = (OMElement) roles.next();
			addField("user.role", role.getText());
		}
	}
}
