/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import org.apache.solr.client.solrj.SolrQuery;
import org.apache.solr.client.solrj.response.QueryResponse;

/**
 * Encapsulates a single Solrj query.
 * @author Fabian Körner
 */
public final class SolrPlainQuery extends AbstractSolrCommand<QueryResponse>
{

	private SolrQuery _query;

	/**
	 * Contructor with plan SolrQuery which will be executed.
	 * @param query Query for execution.
	 * @throws SolrCommandException Could not execute query.
	 */
	public SolrPlainQuery(final SolrQuery query) throws SolrCommandException
	{
		super();
		_query = query;
	}

	/**
	 * @see org.bbaw.pdr.solr.AbstractSolrCommand#execute()
	 * @return Query response.
	 * @throws SolrCommandException Could not successfully execute Solr command.
	 */
	@Override
	public QueryResponse execute() 	throws SolrCommandException
	{
		QueryResponse result;
		try
		{
			result = super.getSolrServer().query(_query);
		}
		catch (Exception cause)
		{
			throw new SolrCommandException(cause);
		}
		return result;
	}
}
